(* file: stripes.ml
 * author: Bob Muller
 *
 * A program for rendering N randomly colored stripes in the
 * graphics window. The code here illustrates the use of recursion
 * to express repetition.
 *
 * Usage: in a Unix shell, type:
 *
 * > make
 * > ./stripes
 *)
open World
open Image
open Color

open Cs1101

let displayWidth = 800.
let displayHeight = displayWidth

(* stripes : int -> Image.t
 *)
let stripes n =
  let width = displayWidth /. (float_of_int n) in
  let empty = Image.empty_scene displayWidth displayHeight in
  let rec repeat m image =
    match m = 0 with
    | true  -> image
    | false -> let color = Cs1101.randomColor() in
	       let stripe = Image.rectangle width displayHeight color in
	       let y = 0.0 in
	       let x = width *. (float_of_int (m - 1)) in
	       let newImage = Image.place_image stripe (x, y) image
	       in
	       repeat (m - 1) newImage
  in
  repeat n empty

(* go : unit -> Image.t
 *
 * This function will be called once every second by the World.big_bang
 * function.
 *)
let go () =
  let n = 1 + (Random.int 8)
  in
  stripes n

let _ = World.big_bang ()
		       ~name:"Stripes!"
		       ~width: (int_of_float displayWidth)
		       ~height:(int_of_float displayHeight)
		       ~to_draw:go
